@@ -46,6 +46,7 @@
 #include "via_id.h"
 
 #include <math.h>
+#include <unistd.h>
 
 /*
  * Warning: this file contains revision checks which are CLE266-specific.
@@ -95,7 +96,8 @@ viaWaitHQVFlip(VIAPtr pVia)
     pdwState = (CARD32 volatile *)(pVia->VidMapBase + (HQV_CONTROL + proReg));
 
     if (pVia->VideoEngine == VIDEO_ENGINE_CME) {
-        while (*pdwState & (HQV_SUBPIC_FLIP | HQV_SW_FLIP)) ;
+        // while (*pdwState & (HQV_SUBPIC_FLIP | HQV_SW_FLIP)) ;
+	while (*pdwState & HQV_SUBPIC_FLIP);
     } else {
         while (!(*pdwState & HQV_FLIP_STATUS)) ;
     }
@@ -280,6 +282,15 @@ VIAVidHWDiffInit(ScrnInfoPtr pScrn)
             HWDiff->dwHQVDisablePatch = VID_HWDIFF_FALSE;
             HWDiff->dwNeedV1Prefetch = VID_HWDIFF_FALSE;
             break;
+        case VIA_VX800:
+        case VIA_VX855:
+            HWDiff->dwThreeHQVBuffer = VID_HWDIFF_TRUE;
+            HWDiff->dwHQVFetchByteUnit = VID_HWDIFF_TRUE;
+            HWDiff->dwSupportTwoColorKey = VID_HWDIFF_TRUE;
+            HWDiff->dwHQVInitPatch = VID_HWDIFF_FALSE;
+            HWDiff->dwHQVDisablePatch = VID_HWDIFF_FALSE;
+            HWDiff->dwNeedV1Prefetch = VID_HWDIFF_FALSE;
+            break;
         default:
             xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
                        "VIAVidHWDiffInit: Unhandled ChipSet.\n");
@@ -774,6 +785,8 @@ viaCalculateVideoColor(VIAPtr pVia, int hue, int saturation,
         case PCI_CHIP_VT3364:
         case PCI_CHIP_VT3324:
         case PCI_CHIP_VT3327:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
             model = 0;
             break;
         case PCI_CHIP_CLE3122:
@@ -911,6 +924,8 @@ viaSetColorSpace(VIAPtr pVia, int hue, int saturation, int brightness,
         case PCI_CHIP_VT3336:
         case PCI_CHIP_VT3324:
         case PCI_CHIP_VT3364:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
         case PCI_CHIP_CLE3122:
             VIDOutD(V1_ColorSpaceReg_2, col2);
             VIDOutD(V1_ColorSpaceReg_1, col1);
@@ -939,6 +954,8 @@ ViaInitVideoStatusFlag(VIAPtr pVia)
         case PCI_CHIP_VT3336:
         case PCI_CHIP_VT3324:
         case PCI_CHIP_VT3364:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
             return (VIDEO_HQV_INUSE | SW_USE_HQV | VIDEO_1_INUSE
                     | VIDEO_ACTIVE | VIDEO_SHOW);
         case PCI_CHIP_CLE3122:
@@ -976,7 +993,10 @@ ViaSetVidCtl(VIAPtr pVia, unsigned int videoFlag)
             case PCI_CHIP_VT3336:
             case PCI_CHIP_VT3324:
             case PCI_CHIP_VT3364:
+            case PCI_CHIP_VT3353:
                 return V3_ENABLE | VIDEO_EXPIRE_NUM_VT3336;
+            case PCI_CHIP_VT3409:
+                return V3_ENABLE | VIDEO_EXPIRE_NUM_VT3409;
             case PCI_CHIP_CLE3122:
                 if (CLE266_REV_IS_CX(pVia->ChipRev))
                     return V3_ENABLE | V3_EXPIRE_NUM_F;
@@ -1256,23 +1276,28 @@ SetFIFO_V1(VIAPtr pVia, CARD8 depth, CARD8 prethreshold, CARD8 threshold)
 static void
 SetFIFO_V3(VIAPtr pVia, CARD8 depth, CARD8 prethreshold, CARD8 threshold)
 {
-    if ((pVia->ChipId == PCI_CHIP_VT3314)
-        || (pVia->ChipId == PCI_CHIP_VT3324)
-        || (pVia->ChipId == PCI_CHIP_VT3327)) {
-        SaveVideoRegister(pVia, ALPHA_V3_FIFO_CONTROL,
-                          (VIDInD(ALPHA_V3_FIFO_CONTROL) & ALPHA_FIFO_MASK)
-                          | ((depth - 1) & 0xff) | ((threshold & 0xff) << 8));
-        SaveVideoRegister(pVia, ALPHA_V3_PREFIFO_CONTROL,
-                          (VIDInD(ALPHA_V3_PREFIFO_CONTROL)
-                           & ~V3_FIFO_MASK_3314) | (prethreshold & 0xff));
-    } else {
-        SaveVideoRegister(pVia, ALPHA_V3_FIFO_CONTROL,
-                          (VIDInD(ALPHA_V3_FIFO_CONTROL) & ALPHA_FIFO_MASK)
-                          | ((depth - 1) & 0xff) | ((threshold & 0xff) << 8));
-        SaveVideoRegister(pVia, ALPHA_V3_PREFIFO_CONTROL,
-                          (VIDInD(ALPHA_V3_PREFIFO_CONTROL) & ~V3_FIFO_MASK)
-                          | (prethreshold & 0x7f));
-    }
+    switch (pVia->ChipId) {
+        case PCI_CHIP_VT3314:
+        case PCI_CHIP_VT3324:
+        case PCI_CHIP_VT3327:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
+            SaveVideoRegister(pVia, ALPHA_V3_FIFO_CONTROL,
+                              (VIDInD(ALPHA_V3_FIFO_CONTROL) & ALPHA_FIFO_MASK)
+                               | ((depth - 1) & 0xff) | ((threshold & 0xff) << 8));
+            SaveVideoRegister(pVia, ALPHA_V3_PREFIFO_CONTROL,
+                              (VIDInD(ALPHA_V3_PREFIFO_CONTROL)
+                              & ~V3_FIFO_MASK_3314) | (prethreshold & 0xff));
+            break;
+        default :
+            SaveVideoRegister(pVia, ALPHA_V3_FIFO_CONTROL,
+                              (VIDInD(ALPHA_V3_FIFO_CONTROL) & ALPHA_FIFO_MASK)
+                              | ((depth - 1) & 0xff) | ((threshold & 0xff) << 8));
+            SaveVideoRegister(pVia, ALPHA_V3_PREFIFO_CONTROL,
+                              (VIDInD(ALPHA_V3_PREFIFO_CONTROL) & ~V3_FIFO_MASK)
+                              | (prethreshold & 0x7f));
+            break;
+    } 
 }
 
 static void
@@ -1320,6 +1345,8 @@ SetFIFO_V3_64or32or32(VIAPtr pVia)
         case PCI_CHIP_VT3336:
         case PCI_CHIP_VT3324:
         case PCI_CHIP_VT3364:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
             SetFIFO_V3(pVia, 225, 200, 250);
             break;
         case PCI_CHIP_VT3204:
@@ -1351,6 +1378,8 @@ SetFIFO_V3_64or32or16(VIAPtr pVia)
         case PCI_CHIP_VT3336:
         case PCI_CHIP_VT3324:
         case PCI_CHIP_VT3364:
+        case PCI_CHIP_VT3353:
+        case PCI_CHIP_VT3409:
             SetFIFO_V3(pVia, 225, 200, 250);
             break;
         case PCI_CHIP_VT3204:
@@ -1624,9 +1653,9 @@ SetVideoWindow(ScrnInfoPtr pScrn, unsigned long videoFlag,
      */
     if (videoFlag & VIDEO_1_INUSE) {
         if (pBIOSInfo->SetDVI && pBIOSInfo->scaleY) {
-            top = (pUpdate->DstTop * pBIOSInfo->panelY
+            top = (pUpdate->DstTop * pBIOSInfo->Panel->NativeMode->Height
                    / pScrn->currentMode->VDisplay);
-            bottom = (pUpdate->DstBottom * pBIOSInfo->panelY
+            bottom = (pUpdate->DstBottom * pBIOSInfo->Panel->NativeMode->Height
                       / pScrn->currentMode->VDisplay);
         }
     }
@@ -1674,6 +1703,7 @@ Upd_Video(ScrnInfoPtr pScrn, unsigned long videoFlag,
           unsigned long chromaKeyLow, unsigned long chromaKeyHigh)
 {
     VIAPtr pVia = VIAPTR(pScrn);
+    VIABIOSInfoPtr pBIOSInfo = pVia->pBIOSInfo;
     vgaHWPtr hwp = VGAHWPTR(pScrn);
     VIAHWDiff *hwDiff = &pVia->HWDiff;
 
@@ -1707,8 +1737,15 @@ Upd_Video(ScrnInfoPtr pScrn, unsigned long videoFlag,
                   pUpdate->DstLeft, pUpdate->DstRight,
                   pUpdate->DstTop, pUpdate->DstBottom));
 
-    pVia->swov.overlayRecordV1.dwWidth = dstWidth =
-            pUpdate->DstRight - pUpdate->DstLeft;
+    dstWidth = pUpdate->DstRight - pUpdate->DstLeft;
+    if (pBIOSInfo->Panel->IsActive && pBIOSInfo->Panel->Scale) {
+        /* FIXME: We need to determine if the panel is using V1 or V3 */
+        float hfactor = (float)pBIOSInfo->Panel->NativeMode->Width
+                        / pScrn->currentMode->HDisplay;
+        dstWidth *= hfactor;
+    }
+
+    pVia->swov.overlayRecordV1.dwWidth = dstWidth;
     pVia->swov.overlayRecordV1.dwHeight = dstHeight =
             pUpdate->DstBottom - pUpdate->DstTop;
     srcWidth = (unsigned long)pUpdate->SrcRight - pUpdate->SrcLeft;
@@ -1727,8 +1764,10 @@ Upd_Video(ScrnInfoPtr pScrn, unsigned long videoFlag,
      * FIXME:
      * Enable video on secondary 
      */
-    if ((pVia->Chipset == VIA_P4M900 || pVia->Chipset == VIA_VM800)
-        && pVia->pBIOSInfo->PanelActive) {
+    if ((pVia->VideoEngine == VIDEO_ENGINE_CME
+         || pVia->Chipset == VIA_VM800)
+        && pVia->pBIOSInfo->Panel->IsActive) {
+
         /* V1_ON_SND_DISPLAY */
         vidCtl |= 0x80000000;
         /* SECOND_DISPLAY_COLOR_KEY_ENABLE */
@@ -1982,6 +2021,15 @@ Upd_Video(ScrnInfoPtr pScrn, unsigned long videoFlag,
         compose = SetChromaKey(pVia, videoFlag, chromaKeyLow, chromaKeyHigh,
                                miniCtl, compose);
 
+    if (pVia->VideoEngine == VIDEO_ENGINE_CME) {
+        VIDOutD(HQV_SRC_DATA_OFFSET_CONTROL1,0);
+        VIDOutD(HQV_SRC_DATA_OFFSET_CONTROL3,((pUpdate->SrcRight - 1 ) << 16) | (pUpdate->SrcBottom - 1));
+        if (pVia->Chipset == VIA_VX800 || pVia->Chipset == VIA_VX855) {
+            VIDOutD(HQV_SRC_DATA_OFFSET_CONTROL2,0);
+            VIDOutD(HQV_SRC_DATA_OFFSET_CONTROL4,((pUpdate->SrcRight - 1 ) << 16) | (pUpdate->SrcBottom - 1));
+        }
+    }
+
     /* Set up video control */
     if (videoFlag & VIDEO_HQV_INUSE) {
 
